import { TrackerPluginInterface, TrackerValidationRuleInterface, TrackerInterface, ContextsConfig, TrackerEvent } from '@objectiv/tracker-core';

/**
 * The PathContextFromURL Plugin gathers the current URL using the Location API.
 * It implements the `enrich` lifecycle method. This ensures the URL is retrieved before each Event is sent.
 *
 * Event Validation:
 *  - Must be present in Global Contexts
 *  - Must not be present multiple times
 */
declare class PathContextFromURLPlugin implements TrackerPluginInterface {
    readonly pluginName = "PathContextFromURLPlugin";
    validationRules: TrackerValidationRuleInterface[];
    initialized: boolean;
    /**
     * Initializes validation rules.
     */
    initialize({ platform }: TrackerInterface): void;
    /**
     * Generate a fresh PathContext before each TrackerEvent is handed over to the TrackerTransport.
     */
    enrich(contexts: Required<ContextsConfig>): void;
    /**
     * If the Plugin is usable runs all validation rules.
     */
    validate(event: TrackerEvent): void;
    /**
     * Make this plugin usable only on web, eg: Document and Location APIs are both available
     */
    isUsable(): boolean;
}

export { PathContextFromURLPlugin };
